==> mono_1.2.2.1.orig.tar.gz: mono-1.2.2.1/mcs/class/System.Design/System.Web.UI.Design/ExpressionEditorSheet.cs <==
//
// System.Web.UI.Design.ExpressionEditorSheet
//
// Authors:
//	Chris Toshok (toshok@ximian.com)
//
// (C) 2006 Novell, Inc (http://www.novell.com)
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

using System;
using System.ComponentModel;

namespace System.Web.UI.Design {

	public abstract class ExpressionEditorSheet
	{
		IServiceProvider serviceProvider;

		public ExpressionEditorSheet (IServiceProvider serviceProvider)
		{
			this.serviceProvider = serviceProvider;
		}

		public abstract string GetExpression ();

		public virtual bool IsValid {
			get {
				throw new NotImplementedException ();
			}
		}

		[Browsable (false)]
		public IServiceProvider ServiceProvider {
			get { return serviceProvider; }
		}
	}

}

#endif

==> mono_4.6.2.7+dfsg.orig.tar.gz: mono-4.6.2+dfsg/mcs/class/System.Design/System.Web.UI.Design/ExpressionEditorSheet.cs <==
//
// System.Web.UI.Design.ExpressionEditorSheet
//
// Authors:
//	Chris Toshok (toshok@ximian.com)
//
// (C) 2006 Novell, Inc (http://www.novell.com)
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//


using System;
using System.ComponentModel;

namespace System.Web.UI.Design {

	public abstract class ExpressionEditorSheet
	{
		IServiceProvider serviceProvider;

		protected ExpressionEditorSheet (IServiceProvider serviceProvider)
		{
			this.serviceProvider = serviceProvider;
		}

		public abstract string GetExpression ();

		[Browsable (false)]
		public virtual bool IsValid {
			get {
				throw new NotImplementedException ();
			}
		}

		[Browsable (false)]
		public IServiceProvider ServiceProvider {
			get { return serviceProvider; }
		}
	}

}
